ImageResolution enum

Inheritance
Available extensions

Values

low → const ImageResolution

352x288 on iOS, 240p (320x240) on Android and Web

medium → const ImageResolution

480p (640x480 on iOS, 720x480 on Android and Web)

high → const ImageResolution

720p (1280x720)

veryHigh → const ImageResolution

1080p (1920x1080)

ultraHigh → const ImageResolution

2160p (3840x2160 on Android and iOS, 4096x2160 on Web)

max → const ImageResolution

The highest resolution available.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
resolutionPreset → ResolutionPreset

Available on ImageResolution, provided by the ImageResolutionExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ImageResolution>
A constant List of the values in this enum, in order of their declaration.